@@ -574,7 +574,7 @@ class FluxAgent:
                         log.error("Error loading extensions packages, skipping")
                         return
                     try:
-                        runner = importlib.import_module(f"{f}/_runner.py")
+                        runner = importlib.import_module(f"{f}_runner")
                     except Exception as e:
                         print(repr(e))
                     else:
